package com.novapp.nova_alarm_plugin;

import android.app.Activity;
import android.content.Intent;

import androidx.annotation.NonNull;

import com.novapp.nova_alarm_plugin.calendar.CalendarReminderUtils;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

import static com.novapp.nova_alarm_plugin.utils.ClockPluginConstant.*;

/**
 * NovaAlarmPlugin
 */
public class NovaAlarmPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {

    private static Activity appContext;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        final MethodChannel channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "nova_alarm_plugin");
        channel.setMethodCallHandler(new NovaAlarmPlugin());
    }

    // This static function is optional and equivalent to onAttachedToEngine. It supports the old
    // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
    // plugin registration via this function while apps migrate to use the new Android APIs
    // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
    //
    // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
    // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
    // depending on the user's project. onAttachedToEngine or registerWith must both be defined
    // in the same class.
    public static void registerWith(Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "nova_alarm_plugin");
        channel.setMethodCallHandler(new NovaAlarmPlugin());
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {

        switch (call.method) {

            case initClockService:
                initClockService();
                break;
            case requestCalendarPermission:
                CalendarReminderUtils.checkCalendarPermission(appContext);
                break;
            case insertCalenderEvent:
                CalendarReminderUtils.addCalendarEvent(appContext, call, result);
                break;

            case deleteCalendarEvent:
                CalendarReminderUtils.deleteCalendarEvent(appContext, call, result);
                break;
            default:
                result.notImplemented();
                break;
        }

    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    }

    @Override
    public void onAttachedToActivity(ActivityPluginBinding binding) {
        appContext = binding.getActivity();
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {

    }

    @Override
    public void onReattachedToActivityForConfigChanges(ActivityPluginBinding binding) {

    }

    @Override
    public void onDetachedFromActivity() {

    }

    private void initClockService() {
        appContext.startService(new Intent(appContext, KeepAliveService.class));
    }
}
